<template>
  <div id="main" style="height: 460px;margin-bottom: 15px">
    <basic-container>
      <v-chart id="chart" :auto-resize="true" :options="chartOptions"></v-chart>
      <div style="display: inline-block;float: right;margin-bottom: 10px;margin-right: 60px">
        <el-button size="small" type="primary" plain @click="delHandler">删除</el-button>
      </div>
    </basic-container>
  </div>
</template>

<script>
import 'echarts'
import 'echarts/lib/chart/line'
import 'echarts/lib/component/tooltip'
import 'echarts/lib/component/title'
import 'echarts/lib/component/legend'
import {deleteChartId} from "@/api/statistic/chart"

export default {
  name: "lineChart",
  props: {
    lineData: {
      type: Array,
      default: []
    },
    chartName: {
      type: String,
      default: ""
    },
    btmname :{
      type: String
    }
  },
  watch: {
    lineData: {
      immediate: true,
      handler(newval, oldval) {
        if (newval) {
          const series = newval.map((data, index) => ({
            name: index === 0 ? '总量' : '新增',
            type: 'line',
            smooth: true,
            stack: index === 0 ? 'Total' : 'total2', // 根据 index 区分总量和新增的堆叠情况
            label: {
              show: true,
              textStyle: {
                fontSize: 14
              }
            },
            data: data.map(value => ({value}))
          }));

          this.chartOptions.series = series;
        }
      }
    },
    chartName: {
      handler(newval, oldval) {
        if (newval) {
          this.chartOptions.title.text = newval + "数据统计"
        }
      },
      immediate: true,
      deep: true
    },
  },
  data() {
    return {
      chartOptions: {
        color: ['#2eadd6', '#FFA500'],
        title: {
          text: ''
        },
        tooltip: {
          trigger: 'axis'
        },
        legend: {
          data: ['总量', '新增'],
          textStyle: {
            fontSize: 14 // 调整字体大小
          }
        },
        xAxis: {
          boundaryGap: true,
          type: 'category',
          data: ['1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月', '10月', '11月', '12月'],
        },
        yAxis: {
          type: 'value',
        },
        series: []
      }
    };
  },
  methods:{
    delHandler(){
      deleteChartId({btmname:this.btmname,chartId:'0'}).then(res=>{
        this.$message.success('删除成功')
        this.$emit('refresh');
      }).catch(error=>{
        this.$message.error(error)
      })
    }
  }
};
</script>

<style lang="scss" scoped>
#chart {
  width: 100%;
  height: 400px;
}

</style>
